==> kendo-validator-react-wrapper-2018.1.117.tgz: package/docs/index.md <==
---
title: Overview
description: "Get an overview of the features the Kendo UI Validator delivers and use the wrapper in React projects."
slug: overview_validator
position: 0
---

# Validator Overview

The Validator supports the validation of values and other types of user input.

The Validator wrapper is a client-side wrapper for the [Kendo UI Validator](http://docs.telerik.com/kendo-ui/api/javascript/ui/validator) widget.

## Basic Usage

The following example demonstrates the Validator in action.

```jsx-preview
class ValidatorContainer extends React.Component {
    constructor(props) {
            super(props);
    }

    render() {
        return (
            <div className="example-wrapper">
                <Validator>
	                <form>
	                    <input className="k-textbox"
	                           type="text"
	                           id="fullname"
	                           name="fullname"
	                           placeholder="Full name"
	                           required={true}
	                    />
						<br /><br />
	                    <button className="k-button k-primary" type="submit">Submit</button>
	                </form>
	            </Validator>                  
            </div>
        );
    }
}
ReactDOM.render(
    <ValidatorContainer/>,
    document.querySelector('my-app')
);
```

## Installation

All components that you reference during the installation will be present in the final bundle of your application. To avoid ending up with components you do not actually need, import only the used component from the package.

1. Download and install the package:

    ```sh
        npm install --save @progress/kendo-validator-react-wrapper
    ```

2. Once installed, import the desired component from the package.

    ```sh
        import { AutoComplete } from '@progress/kendo-validator-react-wrapper';
    ```

3. You are required to install one of the Kendo UI themes to style your components.

## Dependencies

The Validator package requires you to install the following [peer dependencies](https://nodejs.org/en/blog/npm/peer-dependencies/) in your application:

* @progress/kendo-ui

## Suggested Links

* [Kendo UI Validator for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/validator/overview)

==> kendo-validator-react-wrapper-2018.1.131.tgz: package/docs/index.md <==
---
title: Overview
page_title: Validator Overview - Components - Kendo UI Wrappers for React
description: "Get an overview of the features the Kendo UI Validator wrapper for React delivers and use the component in React projects."
slug: overview_validator
position: 0
---

# Validator Overview

The Validator supports the validation of values and other types of user input.

The Validator wrapper for React is a client-side wrapper for the [Kendo UI Validator](http://docs.telerik.com/kendo-ui/api/javascript/ui/validator) widget.

## Basic Usage

The following example demonstrates the Validator in action.

```jsx-preview
class ValidatorContainer extends React.Component {
    constructor(props) {
            super(props);
    }

    render() {
        return (
            <div className="example-wrapper">
                <Validator>
	                <form>
	                    <input className="k-textbox"
	                           type="text"
	                           id="fullname"
	                           name="fullname"
	                           placeholder="Full name"
	                           required={true}
	                    />
						<br /><br />
	                    <button className="k-button k-primary" type="submit">Submit</button>
	                </form>
	            </Validator>                  
            </div>
        );
    }
}
ReactDOM.render(
    <ValidatorContainer/>,
    document.querySelector('my-app')
);
```

## Installation

1. Download and install the package.

    ```sh
        npm install --save @progress/kendo-validator-react-wrapper
    ```

2. Once installed, import the desired component from the package.

    ```sh
        import { AutoComplete } from '@progress/kendo-validator-react-wrapper';
    ```

3. You are required to install one of the Kendo UI themes to style your components.

## Dependencies

The Validator package requires you to install the following [peer dependencies](https://nodejs.org/en/blog/npm/peer-dependencies/) in your application:

* @progress/kendo-ui

## Suggested Links

* [Kendo UI Validator for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/validator/overview)
* [API Reference of the Validator Widget](http://docs.telerik.com/kendo-ui/api/javascript/ui/validator)
